/*
* JBoss, Home of Professional Open Source
* Copyright 2006, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.test.classloader.test;

import org.jboss.test.BaseTestCase;
import org.jboss.test.classloader.FilteringClassLoader;
import org.jboss.test.classloader.support.filtered.Filtered;
import org.jboss.test.classloader.support.filtered2.Filtered2;
import org.jboss.test.classloader.support.unfiltered.Unfiltered;

/**
 * FilteringClassLoaderUnitTestCase.
 * 
 * @author <a href="adrian@jboss.com">Adrian Brock</a>
 * @version $Revision: 1.1 $
 */
public class FilteringClassLoaderUnitTestCase extends BaseTestCase
{
   Class filtered = Filtered.class;
   String filteredClassName = filtered.getName();
   String filteredPackage = filtered.getPackage().getName();
   String filteredPath = filteredPackage.replace('.', '/');
   Class filtered2 = Filtered2.class;
   String filtered2ClassName = filtered2.getName();
   String filtered2Package = filtered2.getPackage().getName();
   String filtered2Path = filtered2Package.replace('.', '/');

   Class unfiltered = Unfiltered.class;
   String unfilteredClassName = unfiltered.getName();
   String unfilteredPackage = unfiltered.getPackage().getName();
   String unfilteredPath = unfilteredPackage.replace('.', '/');
   
   public FilteringClassLoaderUnitTestCase(String name)
   {
      super(name);
   }
   
   public void testFilteredClass() throws Exception
   {
      ClassLoader cl = getClass().getClassLoader();
      assertNotNull(cl.loadClass(filteredClassName));
      assertNotNull(cl.loadClass(unfilteredClassName));
      
      String[] packages = { filteredPackage };
      cl = createFilteringClassLoader(cl, packages);
      try
      {
         cl.loadClass(filteredClassName);
         fail("Should not be here");
      }
      catch (Throwable t)
      {
         checkThrowable(ClassNotFoundException.class, t);
      }
      
      assertNotNull(cl.loadClass(unfilteredClassName));
   }
   
   public void testFilteredResource() throws Exception
   {
      ClassLoader cl = getClass().getClassLoader();
      assertNotNull(cl.getResource(filteredPath + "/filtered"));
      assertNotNull(cl.getResource(unfilteredPath + "/unfiltered"));
      
      String[] packages = { filteredPackage };
      cl = createFilteringClassLoader(cl, packages);
      assertNull(cl.getResource(filteredPath + "/" + "filtered"));
      
      assertNotNull(cl.getResource(unfilteredPath + "/unfiltered"));
   }
   
   public void testFilteredResources() throws Exception
   {
      ClassLoader cl = getClass().getClassLoader();
      assertTrue(cl.getResources(filteredPath + "/filtered").hasMoreElements());
      assertTrue(cl.getResources(unfilteredPath + "/unfiltered").hasMoreElements());
      
      String[] packages = { filteredPackage };
      cl = createFilteringClassLoader(cl, packages);
      assertFalse(cl.getResources(filteredPath + "/" + "filtered").hasMoreElements());
      
      assertTrue(cl.getResources(unfilteredPath + "/unfiltered").hasMoreElements());
   }
   
   public void testFilteredClass2() throws Exception
   {
      ClassLoader cl = getClass().getClassLoader();
      assertNotNull(cl.loadClass(filteredClassName));
      assertNotNull(cl.loadClass(filtered2ClassName));
      assertNotNull(cl.loadClass(unfilteredClassName));
      
      String[] packages = { filteredPackage, filtered2Package };
      cl = createFilteringClassLoader(cl, packages);
      try
      {
         cl.loadClass(filteredClassName);
         fail("Should not be here");
      }
      catch (Throwable t)
      {
         checkThrowable(ClassNotFoundException.class, t);
      }
      try
      {
         cl.loadClass(filtered2ClassName);
         fail("Should not be here");
      }
      catch (Throwable t)
      {
         checkThrowable(ClassNotFoundException.class, t);
      }
      
      assertNotNull(cl.loadClass(unfilteredClassName));
   }
   
   public void testFilteredResource2() throws Exception
   {
      ClassLoader cl = getClass().getClassLoader();
      assertNotNull(cl.getResource(filteredPath + "/filtered"));
      assertNotNull(cl.getResource(filtered2Path + "/filtered2"));
      assertNotNull(cl.getResource(unfilteredPath + "/unfiltered"));
      
      String[] packages = { filteredPackage, filtered2Package };
      cl = createFilteringClassLoader(cl, packages);
      assertNull(cl.getResource(filteredPath + "/" + "filtered"));
      assertNull(cl.getResource(filtered2Path + "/" + "filtered2"));
      
      assertNotNull(cl.getResource(unfilteredPath + "/unfiltered"));
   }
   
   public void testFilteredResources2() throws Exception
   {
      ClassLoader cl = getClass().getClassLoader();
      assertTrue(cl.getResources(filteredPath + "/filtered").hasMoreElements());
      assertTrue(cl.getResources(filtered2Path + "/filtered2").hasMoreElements());
      assertTrue(cl.getResources(unfilteredPath + "/unfiltered").hasMoreElements());
      
      String[] packages = { filteredPackage, filtered2Package };
      cl = createFilteringClassLoader(cl, packages);
      assertFalse(cl.getResources(filteredPath + "/" + "filtered").hasMoreElements());
      assertFalse(cl.getResources(filtered2Path + "/" + "filtered2").hasMoreElements());
      
      assertTrue(cl.getResources(unfilteredPath + "/unfiltered").hasMoreElements());
   }
   
   protected ClassLoader createFilteringClassLoader(ClassLoader cl, String[] packages)
   {
      return new FilteringClassLoader(cl, packages);
   }
}
